==> hn-main-consultancy-api-1.0-20250919.085210-11-sources.jar: com/beiming/odr/consultancy/utils/sm4util/EncryptDecryptUtilCopy.java <==
package com.beiming.odr.consultancy.utils.sm4util;


import com.beiming.odr.consultancy.annotation.EncryptDecryptField;
import java.lang.reflect.Field;
import java.util.Objects;
import org.apache.commons.lang3.StringUtils;

/**
 * @author HUAWEI
 * @date 2022/08/23
 */
public class EncryptDecryptUtilCopy {

  /**
   * 数据加密
   *
   * @param declaredFields paramsObject所声明的字段
   * @param paramsObject   mapper中paramsType的实例
   * @return T
   * @throws IllegalAccessException 字段不可访问异常
   */
  public static <T> T encrypt(Field[] declaredFields, T paramsObject) throws IllegalAccessException {
    for (Field field : declaredFields) {
      //取出所有被EncryptDecryptField注解的字段
      EncryptDecryptField sensitiveField = field.getAnnotation(EncryptDecryptField.class);
      if (!Objects.isNull(sensitiveField)) {
        field.setAccessible(true);
        Object object = field.get(paramsObject);
        //暂时只实现String类型的加密
        if (object instanceof String) {
          String value = (String) object;
          //加密
          if (StringUtils.isNotEmpty(value) && !checkIsEncrypt(value)) {
            //xy_db_encrypt_ 加密统一增加前缀字符串 用于避免数据重复加密标识位
            field.set(paramsObject, "xy_db_encrypt_" + SM4Utils.encryptDataCbc(value));
          } else {
            field.set(paramsObject, value);
          }
        }
      }
    }
    return paramsObject;
  }

  /**
   * 数据解密
   *
   * @param result resultType的实例
   * @return T
   * @throws IllegalAccessException 字段不可访问异常
   */
  public static <T> T decrypt(T result) throws IllegalAccessException {
    //取出resultType的类
    Class<?> resultClass = result.getClass();
    Field[] declaredFields = resultClass.getDeclaredFields();
    for (Field field : declaredFields) {
      //取出所有被EncryptDecryptField注解的字段
      EncryptDecryptField sensitiveField = field.getAnnotation(EncryptDecryptField.class);
      if (!Objects.isNull(sensitiveField)) {
        field.setAccessible(true);
        Object object = field.get(result);
        //只支持String的解密
        if (object instanceof String) {
          String value = (String) object;
          if (StringUtils.isNotEmpty(value) && checkIsEncrypt(value)) {
            //去除加密字符串的前缀 xy_db_encrypt_
            field.set(result, SM4Utils.decryptDataCbc(value.substring(14, value.length())));
          } else {
            field.set(result, value);
          }
        }
      }
    }
    return result;
  }

  /**
   * 判断数据是否已经加密过,避免数据重复加密。
   *
   * @param source 数据
   * @return true 未加密 false 已经加密
   */
  private static Boolean checkIsEncrypt(String source) {
    return source.contains("xy_db_encrypt_");
  }

  public static void main(String[] args) {
    String value = "xy_db_encrypt_jSGORToDFKb9KTZ/nwnDDA==";
    String s = SM4Utils.decryptDataCbc(value.substring(14, value.length()));
    System.out.println(s);
  }
}

==> hn-main-consultancy-api-1.0-20251010.060650-14-sources.jar: com/beiming/odr/consultancy/utils/sm4util/EncryptDecryptUtilCopy.java <==
package com.beiming.odr.consultancy.utils.sm4util;


import com.beiming.odr.consultancy.annotation.EncryptDecryptField;
import java.lang.reflect.Field;
import java.util.Objects;
import org.apache.commons.lang3.StringUtils;

/**
 * @author HUAWEI
 * @date 2022/08/23
 */
public class EncryptDecryptUtilCopy {

  /**
   * 数据加密
   *
   * @param declaredFields paramsObject所声明的字段
   * @param paramsObject   mapper中paramsType的实例
   * @return T
   * @throws IllegalAccessException 字段不可访问异常
   */
  public static <T> T encrypt(Field[] declaredFields, T paramsObject) throws IllegalAccessException {
    for (Field field : declaredFields) {
      //取出所有被EncryptDecryptField注解的字段
      EncryptDecryptField sensitiveField = field.getAnnotation(EncryptDecryptField.class);
      if (!Objects.isNull(sensitiveField)) {
        field.setAccessible(true);
        Object object = field.get(paramsObject);
        //暂时只实现String类型的加密
        if (object instanceof String) {
          String value = (String) object;
          //加密
          if (StringUtils.isNotEmpty(value) && !checkIsEncrypt(value)) {
            //xy_db_encrypt_ 加密统一增加前缀字符串 用于避免数据重复加密标识位
            field.set(paramsObject, "xy_db_encrypt_" + SM4Utils.encryptDataCbcCopy(value));
          } else {
            field.set(paramsObject, value);
          }
        }
      }
    }
    return paramsObject;
  }

  /**
   * 数据解密
   *
   * @param result resultType的实例
   * @return T
   * @throws IllegalAccessException 字段不可访问异常
   */
  public static <T> T decrypt(T result) throws IllegalAccessException {
    //取出resultType的类
    Class<?> resultClass = result.getClass();
    Field[] declaredFields = resultClass.getDeclaredFields();
    for (Field field : declaredFields) {
      //取出所有被EncryptDecryptField注解的字段
      EncryptDecryptField sensitiveField = field.getAnnotation(EncryptDecryptField.class);
      if (!Objects.isNull(sensitiveField)) {
        field.setAccessible(true);
        Object object = field.get(result);
        //只支持String的解密
        if (object instanceof String) {
          String value = (String) object;
          if (StringUtils.isNotEmpty(value) && checkIsEncrypt(value)) {
            //去除加密字符串的前缀 xy_db_encrypt_
            field.set(result, SM4Utils.decryptDataCbcCopy(value.substring(14, value.length())));
          } else {
            field.set(result, value);
          }
        }
      }
    }
    return result;
  }

  /**
   * 判断数据是否已经加密过,避免数据重复加密。
   *
   * @param source 数据
   * @return true 未加密 false 已经加密
   */
  private static Boolean checkIsEncrypt(String source) {
    return source.contains("xy_db_encrypt_");
  }

  public static void main(String[] args) {
    String value = "xy_db_encrypt_jSGORToDFKb9KTZ/nwnDDA==";
    String s = SM4Utils.decryptDataCbcCopy(value.substring(14, value.length()));
    System.out.println(s);
  }
}
